/*
 * Copyright (c) 1995, 1996, 1997, 1998, 1999 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 * 
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/* Copyright (C) 1999  Carnegie Mellon University
 * Extensions and modifications to Arla code base for Coda by
 * Philip A. Nelson
 */

/* Started with: xfs_wrap.c,v 1.5 1999/05/27 15:14:59 assar Exp */
/* $Id: coda_wrap.c,v 1.1 1999/10/19 17:52:08 phil Exp $ */

/*
 * Load external FS using modload under Solaris
 *
 * This is a filsystem, a pseudo device driver and a
 * systemcall.
 */

#include <coda.h>
#include <coda_sys.h>
#include <coda_dev.h>
#include <coda_debug.h>

extern struct modldrv coda_modldrv;

extern struct modlfs coda_modlfs;

static struct modlinkage coda_modlinkage = {
    MODREV_1,
    {(void *)&coda_modldrv,
     (void *)&coda_modlfs,
     NULL}
};

int
_init(void)
{
    int ret;

    CODADEB(CDEBLKM, (CE_NOTE, "running _init\n"));
    ret = coda_dev_init();
    if (ret)
	return ret;

    ret = mod_install(&coda_modlinkage);
    if (ret) {
	coda_dev_fini();
    }
    CODADEB(CDEBLKM, (CE_NOTE, "end of _init, ret=%d\n", ret));
    return ret;
}

int
_fini(void)
{
    int ret;

    CODADEB(CDEBLKM, (CE_NOTE, "running _fini\n"));
    ret = mod_remove(&coda_modlinkage);
    if (ret)
	return ret;
    coda_dev_fini();
    return ret;
}

int
_info(struct modinfo *modinfop)
{
    return mod_info(&coda_modlinkage, modinfop);
}
